@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -69,22 +69,22 @@ public class ClearGenConfTables extends ContextDelete {
         super();
     }
 
-    public void deletePerformed(DeleteEvent event, Connection readCon, Connection writeCon) throws DeleteFailedException {
+    public void deletePerformed(final DeleteEvent event, final Connection readCon, final Connection writeCon) throws DeleteFailedException {
         if (!isContextDelete(event)) {
             return;
         }
-        for (String sqlDelete : sqlDeletes) {
+        for (final String sqlDelete : sqlDeletes) {
             execute(event.getContext().getContextId(), writeCon, sqlDelete);
         }
     }
 
-    private void execute(int cid, Connection con, String sql) throws DeleteFailedException {
+    private void execute(final int cid, final Connection con, final String sql) throws DeleteFailedException {
         PreparedStatement stmt = null;
         try {
             stmt = con.prepareStatement(sql);
             stmt.setInt(1, cid);
             stmt.executeUpdate();
-        } catch (SQLException e) {
+        } catch (final SQLException e) {
             throw new DeleteFailedException(Code.SQL_ERROR, e, e.getMessage());
         } finally {
             closeSQLStuff(stmt);
